@@ -8,7 +8,9 @@ import gevent
 from gevent import socket
 from gevent.wsgi import WSGIServer
 
-from .utils import get_ip_address
+from ouimeaux.utils import get_ip_address
+from ouimeaux.device.insight import Insight
+from ouimeaux.signals import subscription
 
 
 log = logging.getLogger(__name__)
@@ -30,7 +32,7 @@ class SubscriptionRegistry(object):
         self._resubscribe(device.basicevent.eventSubURL)
 
     def _resubscribe(self, url, sid=None):
-        headers = {'TIMEOUT': 'infinite'}
+        headers = {'TIMEOUT': 300}
         if sid is not None:
             headers['SID'] = sid
         else:
@@ -42,18 +44,27 @@ class SubscriptionRegistry(object):
 
         response = requests.request(method="SUBSCRIBE", url=url,
                                     headers=headers)
-
+        if response.status_code == 412 and sid:
+            # Invalid subscription ID. Send an UNSUBSCRIBE for safety and
+            # start over.
+            requests.request(method='UNSUBSCRIBE', url=url,
+                    headers={'SID':sid})
+            return self._resubscribe(url)
         timeout = int(response.headers.get('timeout', '1801').replace(
             'Second-', ''))
-        sid = response.headers.get('sid', sid)
-        gevent.spawn_later(timeout - 1, self._resubscribe, url, sid)
+        sid = response.headers.get('sid', sid) 
+        gevent.spawn_later(timeout-1, self._resubscribe, url, sid)
 
     def _handle(self, environ, start_response):
         device = self._devices[environ['REMOTE_ADDR']]
         doc = cElementTree.parse(environ['wsgi.input'])
         for propnode in doc.findall('./{0}property'.format(NS)):
             for property_ in propnode.getchildren():
-                self._event(device, property_.tag, property_.text)
+                text = property_.text
+                if isinstance(device, Insight) and property_.tag=='BinaryState':
+                    text = text.split('|')[0]
+                subscription.send(device, type=property_.tag, value=text)
+                self._event(device, property_.tag, text)
         start_response('200 OK', [
             ('Content-Type', 'text/html'), 
             ('Content-Length', len(SUCCESS)),
